'' =================================================================================================
''
''   File....... jm_i2c_sniffer.spin
''   Purpose.... 
''   Author..... Jon "JonnyMac" McPhalen
''               Copyright (c) 2015 Jon McPhalen
''               -- see below for terms of use
''   E-mail..... jon@jonmcphalen.com
''   Started.... 
''   Updated.... 08 JAN 2015
''
'' =================================================================================================


con { timing }

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000                                           ' use 5MHz crystal

  CLK_FREQ = (_clkmode >> 6) * _xinfreq                          ' system freq as a constant
  MS_001   = CLK_FREQ / 1_000                                    ' ticks in 1ms
  US_001   = CLK_FREQ / 1_000_000                                ' ticks in 1us


con { io pins }

  RX1 = 31                                                       ' programming / terminal
  TX1 = 30                                                        
                                                                  
  SDA = 29                                                       ' eeprom / i2c
  SCL = 28                                                        
                                                                  
                                                                  
con                                                               
                                                                  
  #0, LSBFIRST, MSBFIRST                                          
                                                                  
                                                                  
con { pst formatting }                                            
                                                                  
   #1, HOME, GOTOXY, #8, BKSP, TAB, LF, CLREOL, CLRDN, CR         
  #14, GOTOX, GOTOY, CLS                                          
                                                                  
                                                                  
obj                                                               
                                                                  
  term : "fullduplexserial"
  i2c  : "jm_i2c"                                     
                                                                  
                                                                  
var                                                               
                                                                  
                                                                  
pub main | device                                                         
                                                                  
  setup                                                           
                                                                  
  term.rxflush                                                   ' wait open terminal & keypress
  term.rx                                                         
  term.tx(CLS)

  term.str(string("I2C Buss Sniffer", CR, CR))

  repeat device from %0000_000 to %1111_111
    term.bin(device << 1, 8)
    repeat 4
      term.tx(" ")
    term.hex(device << 1, 2)
    repeat 4
      term.tx(" ")
    if (i2c.present(device << 1))
      term.str(string("Found"))
    term.tx(CR)
    pause(100)                                                        
                                                             
                                                                  
pub setup                                                         
                                                                  
'' Setup IO and objects for application                           
                                                                  
  term.start(RX1, TX1, %0000, 115_200)                           ' start serial for terminal
  i2c.setup                                                      ' use boot eeprom pins                        
                                                                  
                                                                  
con                                                               
                                                                  
  { ------------- }                                               
  {  B A S I C S  }                                               
  { ------------- }                                               
                                                                  
                                                                  
pub pause(ms) | t                                                 
                                                                  
'' Delay program in milliseconds                                  
                                                                  
  if (ms < 1)                                                    ' delay must be > 0
    return                                                        
  else                                                            
    t := cnt - 1776                                              ' sync with system counter
    repeat ms                                                    ' run delay
      waitcnt(t += MS_001)                                        
                                                                  
                                                                  
pub high(pin)                                                     
                                                                  
'' Makes pin output and high                                      
                                                                  
  outa[pin] := 1                                                  
  dira[pin] := 1                                                  
                                                                  
                                                                  
pub low(pin)                                                      
                                                                  
'' Makes pin output and low                                       
                                                                  
  outa[pin] := 0                                                  
  dira[pin] := 1                                                  
                                                                  
                                                                  
pub toggle(pin)                                                   
                                                                  
'' Toggles pin state                                              
                                                                  
  !outa[pin]                                                      
  dira[pin] := 1                                                  
                                                                  
                                                                  
pub input(pin)                                                    
                                                                  
'' Makes pin input and returns current state                      
                                                                  
  dira[pin] := 0                                                  
                                                                  
  return ina[pin]                                                 
                                                                  

dat { license }

{{

  Terms of Use: MIT License

  Permission is hereby granted, free of charge, to any person obtaining a copy of this
  software and associated documentation files (the "Software"), to deal in the Software
  without restriction, including without limitation the rights to use, copy, modify,
  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be included in all copies
  or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
  PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

}}  